@@ -185,8 +185,11 @@ public:
   // Returns a newly allocated string describing these rights
   nsresult CreateACLRightsString(nsAString& rightsString);
 
-protected:
   nsresult GetRightsStringForUser(const nsACString& userName, nsCString &rights);
+
+  nsresult GetOtherUsers(nsIUTF8StringEnumerator** aResult);
+
+protected:
   PRBool GetFlagSetInRightsForUser(const nsACString& userName, char flag, PRBool defaultIfNotFound);
   void BuildInitialACLFromCache();
   void UpdateACLCache();
@@ -355,7 +358,7 @@ protected:
   void FindKeysToAdd(const nsTArray<nsMsgKey> &existingKeys, nsTArray<nsMsgKey>
     &keysToFetch, PRUint32 &numNewUnread, nsIImapFlagAndUidState *flagState);
   void FindKeysToDelete(const nsTArray<nsMsgKey> &existingKeys, nsTArray<nsMsgKey>
-    &keysToFetch, nsIImapFlagAndUidState *flagState);
+    &keysToFetch, nsIImapFlagAndUidState *flagState, PRUint32 boxFlags);
   void PrepareToAddHeadersToMailDB(nsIImapProtocol* aProtocol, const
     nsTArray<nsMsgKey> &keysToFetch,
     nsIMailboxSpec *boxSpec);
